commit 29a06526681e79bf7744966e8ff379b34d71efe0
Author: Leszek Koltunski <leszek@distoretedandroid.org>
Date:   Fri Feb 10 11:20:48 2017 +0000

    Minor

diff --git a/src/main/java/org/distorted/library/Distorted.java b/src/main/java/org/distorted/library/Distorted.java
index 5c619a4..016d8ea 100644
--- a/src/main/java/org/distorted/library/Distorted.java
+++ b/src/main/java/org/distorted/library/Distorted.java
@@ -42,7 +42,7 @@ public class Distorted
    * This way we can have two DistortedTextures, both backed up by the same Bitmap, to which we can
    * apply different effects. Used in the copy constructor.
    */
-  public static final int CLONE_RENDERABLE = 0x1;
+  public static final int CLONE_SURFACE = 0x1;
   /**
    * When creating an instance of a DistortedEffects from another instance, clone the Matrix Effects.
    * <p>
diff --git a/src/main/java/org/distorted/library/DistortedInputSurface.java b/src/main/java/org/distorted/library/DistortedInputSurface.java
index 52c28e1..0e63ae4 100644
--- a/src/main/java/org/distorted/library/DistortedInputSurface.java
+++ b/src/main/java/org/distorted/library/DistortedInputSurface.java
@@ -20,7 +20,6 @@
 package org.distorted.library;
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
-
 /**
  * A Surface that we can set as Input, i.e. take its rectangle of pixels and skin our Mesh with it.
  */
diff --git a/src/main/java/org/distorted/library/DistortedSurface.java b/src/main/java/org/distorted/library/DistortedSurface.java
index 4770090..0b6d141 100644
--- a/src/main/java/org/distorted/library/DistortedSurface.java
+++ b/src/main/java/org/distorted/library/DistortedSurface.java
@@ -79,10 +79,10 @@ abstract class DistortedSurface
 
   static synchronized void onDestroy()
     {
-    for( DistortedSurface ren : mList)
+    for( DistortedSurface surface : mList)
       {
-      ren.destroy();
-      ren.mMarked = false;
+      surface.destroy();
+      surface.mMarked = false;
       }
 
     mListMarked = false;
diff --git a/src/main/java/org/distorted/library/DistortedTree.java b/src/main/java/org/distorted/library/DistortedTree.java
index c9ab947..995fa69 100644
--- a/src/main/java/org/distorted/library/DistortedTree.java
+++ b/src/main/java/org/distorted/library/DistortedTree.java
@@ -281,9 +281,9 @@ public class DistortedTree
  *     
  * @param node The DistortedTree to copy data from.
  * @param flags bit field composed of a subset of the following:
- *        {@link Distorted#CLONE_RENDERABLE},  {@link Distorted#CLONE_MATRIX}, {@link Distorted#CLONE_VERTEX},
+ *        {@link Distorted#CLONE_SURFACE},  {@link Distorted#CLONE_MATRIX}, {@link Distorted#CLONE_VERTEX},
  *        {@link Distorted#CLONE_FRAGMENT} and {@link Distorted#CLONE_CHILDREN}.
  *        For example flags = CLONE_RENDERABLE | CLONE_CHILDREN.
  */
   public DistortedTree(DistortedTree node, int flags)
     {
@@ -291,7 +291,7 @@ public class DistortedTree
     mEffects= new DistortedEffects(node.mEffects,flags);
     mMesh = node.mMesh;
 
-    if( (flags & Distorted.CLONE_RENDERABLE) != 0 )
+    if( (flags & Distorted.CLONE_SURFACE) != 0 )
       {
       mSurface = node.mSurface;
       }
@@ -281,9 +281,9 @@ public class DistortedTree
  *        {@link Distorted#CLONE_FRAGMENT} and {@link Distorted#CLONE_CHILDREN}.
- *        For example flags = CLONE_RENDERABLE | CLONE_CHILDREN.
+ *        For example flags = CLONE_SURFACE | CLONE_CHILDREN.
  */
   public DistortedTree(DistortedTree node, int flags)
